/**
 * Predefined error codes.
 */
var ErrorCodes;
(function (ErrorCodes) {
  // Defined by JSON-RPC 2.0.
  ErrorCodes.ParseError = -32700;
  ErrorCodes.InvalidRequest = -32600;
  ErrorCodes.MethodNotFound = -32601;
  ErrorCodes.InvalidParams = -32602;
  ErrorCodes.InternalError = -32603;
  ErrorCodes.serverErrorStart = -32099;
  ErrorCodes.serverErrorEnd = -32e3;
  ErrorCodes.ServerNotInitialized = -32002;
  ErrorCodes.UnknownErrorCode = -32001;
  // Defined by this library.
  ErrorCodes.MessageWriteError = 1;
  ErrorCodes.MessageReadError = 2;
  ErrorCodes.RequestAborted = -32800;
})(ErrorCodes || (ErrorCodes = {}));
/**
 * An error object return in a response in case a request
 * has failed.
 */
class ResponseError extends Error {
  code;
  data;
  constructor(code, message, data) {
    super(message);
    this.code = typeof code === 'number' ? code : ErrorCodes.UnknownErrorCode;
    this.data = data;
    Object.setPrototypeOf(this, ResponseError.prototype);
  }
  toJSON() {
    return {
      code: this.code,
      message: this.message,
      data: this.data
    };
  }
}
/**
 * Tests if the given message is a request message
 */
function isRequestMessage(message) {
  const candidate = message;
  return candidate && typeof candidate.method === 'string' && (typeof candidate.id === 'string' || typeof candidate.id === 'number');
}
/**
 * Tests if the given message is a notification message
 */
function isNotificationMessage(message) {
  const candidate = message;
  return candidate && typeof candidate.method === 'string' && message.id === void 0;
}
/**
 * Tests if the given message is a response message
 */
function isResponseMessage(message) {
  const candidate = message;
  return candidate && (candidate.result !== void 0 || !!candidate.error || !!candidate.complete) && (typeof candidate.id === 'string' || typeof candidate.id === 'number' || candidate.id === null);
}export{ErrorCodes,ResponseError,isNotificationMessage,isRequestMessage,isResponseMessage};//# sourceMappingURL=messages.js.map
