import { ObservableInput, Unsubscribable } from 'rxjs';
import { IContributionsItem, IContributions } from './contribution';
/** A registered set of contributions from an extension in the registry. */
/**
 * The contributions, either as a value or an observable.
 *
 * If an observable is used, it should be a cold Observable and emit (e.g., its current value) upon
 * subscription. The {@link ContributionRegistry#contributions} observable blocks until all observables have
 * emitted.
 */
export type IContributionsEntry = IContributionsItem | {
    [id: string]: ObservableInput<IContributions | IContributions[]>;
};
/**
 * An unsubscribable that deregisters the contributions it is associated with. It can also be used in
 * ContributionRegistry#replaceContributions.
 */
export interface IContributionUnsubscribable extends Unsubscribable {
    entry: IContributionsEntry;
}
